// Copyright 2023 Specter Ops, Inc.
//
// Licensed under the Apache License, Version 2.0
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
//
// SPDX-License-Identifier: Apache-2.0

package integration

import (
	"time"

	"github.com/specterops/bloodhound/cmd/api/src/model"
	"github.com/stretchr/testify/require"
)

func (s *Context) GetLatestAuditLogs() model.AuditLogs {
	auditLogsResponse, err := s.AdminClient().GetLatestAuditLogs()

	require.Nilf(s.TestCtrl, err, "Failed fetching latest audit logs: %v", err)
	return auditLogsResponse.Logs
}

func (s *Context) ListAuditLogs(after, before time.Time, offset, limit int) model.AuditLogs {
	auditLogsResponse, err := s.AdminClient().ListAuditLogs(after, before, offset, limit)

	require.Nilf(s.TestCtrl, err, "Failed fetching audit logs: %v", err)
	return auditLogsResponse.Logs
}
